@@ -144,6 +144,30 @@ changes to SVN automatically.
 History
 -------
 
+hgsvn 0.1.5
+-----------
+
+Improvements:
+
+* In the initial import, parse the svn:ignore property and add suggestions to
+  the .hgignore file accordingly. These suggestions are commented by default
+  because they are based on the latest version of the svn:ignore property and
+  could make us miss some files along the SVN history, if enabled blindingly.
+
+Bug fixes:
+
+* Critical fix for Mercurial 0.9.5, which is stricter with named branches.
+  This bug made ``hgimportsvn`` fail when cloning from an auto-detected parent
+  repository.
+* Honor the SVN_ASP_DOT_NET_HACK environment variable when deciding the name
+  of private SVN folders (``.svn`` or ``_svn``). Thanks to Anton Daneika for
+  the report and the original patch.
+
+Packaging:
+
+* Change setuptools options to solve bdist_rpm bug under Fedora and other
+  Linux distributions. Patch by Tim Wegener.
+
 hgsvn 0.1.4
 -----------
 
@@ -235,7 +259,7 @@ __all__ = []
 
 __author__ = 'Antoine Pitrou'
 __license__ = 'GNU General Public License (version 3 or later)'
-__versioninfo__ = (0, 1, 4)
+__versioninfo__ = (0, 1, 5)
 
 base_version = '.'.join(map(str, __versioninfo__))
 full_version = base_version
