@@ -14,9 +14,14 @@ try:
 except ImportError:
     commands = None
 
+if "SVN_ASP_DOT_NET_HACK" in os.environ:
+    svn_private_dir = "_svn"
+else:
+    svn_private_dir = '.svn'
+
 hg_commit_prefix = "[svn] "
 # This seems sufficient for excluding all .svn (sub)directories
-hg_exclude_options = ["-X", ".svn", "-X", "**/.svn"]
+hg_exclude_options = ["-X", svn_private_dir, "-X", "**/%s" % svn_private_dir]
 
 
 # Windows compatibility code by Bill Baxter
